#
# spec file for package chromaprint
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname      1
%bcond_without ffmpeg
Name:           chromaprint
Version:        1.3.1
Release:        2.3
Summary:        Audio Fingerprinting Library
License:        GPL-2.0+
Group:          System/Libraries
Url:            http://acoustid.org/chromaprint
Source0:        https://bitbucket.org/acoustid/chromaprint/downloads/chromaprint-%{version}.tar.gz
Source1:        baselibs.conf
Patch0:         chromaprint-ffmpeg-pkgconfig.patch
Patch1:         chromaprint-ffmpeg-API.patch
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  fftw3-devel
BuildRequires:  gcc-c++
BuildRequires:  libtag-devel
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with ffmpeg}
BuildRequires:  boost-devel
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavresample)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswresample)
%endif

%description
Chromaprint is the core component of the Acoustid project. It's a client-side
library that implements a custom algorithm for extracting fingerprints from any
audio source.

%package -n libchromaprint%{soname}
Summary:        Audio Fingerprinting Library
License:        LGPL-2.1+
Group:          System/Libraries

%description -n libchromaprint%{soname}
Chromaprint is the core component of the Acoustid project. It's a client-side
library that implements a custom algorithm for extracting fingerprints from any
audio source.

%package -n libchromaprint-devel
Summary:        Audio Fingerprinting Library
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Requires:       fftw3-devel
Requires:       libchromaprint%{soname} = %{version}
Requires:       libtag-devel

%description -n libchromaprint-devel
Chromaprint is the core component of the Acoustid project. It's a client-side
library that implements a custom algorithm for extracting fingerprints from any
audio source.

%if %{with ffmpeg}
%package fpcalc
Summary:        Chromaprint Audio Fingerprinting Command Line Tool
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       libchromaprint%{soname} = %{version}
Provides:       fpcalc = %{version}

%description fpcalc
Chromaprint is the core component of the Acoustid project. It's a client-side
library that implements a custom algorithm for extracting fingerprints from any
audio source.
This package contains fpcalc, a command-line tool to perform Chromaprint
fingerprinting.
%endif

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
%cmake \
    -DCMAKE_SKIP_RPATH=TRUE \
    -DCMAKE_BUILD_WITH_INSTALL_RPATH=FALSE \
%if %{with ffmpeg}
    -DWITH_AVFFT=ON \
    -DBUILD_EXAMPLES=ON \
%endif

make %{?_smp_mflags}

%install
%cmake_install

%post   -n libchromaprint%{soname} -p /sbin/ldconfig

%postun -n libchromaprint%{soname} -p /sbin/ldconfig

%files -n libchromaprint%{soname}
%defattr(-,root,root)
%doc COPYING.txt NEWS.txt README.md
%{_libdir}/libchromaprint.so.%{soname}
%{_libdir}/libchromaprint.so.%{soname}.*

%files -n libchromaprint-devel
%defattr(-,root,root)
%{_includedir}/chromaprint.h
%{_libdir}/libchromaprint.so
%{_libdir}/pkgconfig/libchromaprint.pc

%if %{with ffmpeg}
%files fpcalc
%defattr(-,root,root)
%{_bindir}/fpcalc
%endif

%changelog
* Thu Jul 28 2016 olaf@aepfle.de
- Remove unused Provides libchromaprint-with-ffmpeg
* Fri Apr  1 2016 olaf@aepfle.de
- Restore support for libswresample/libavresample (bsc#973555)
- Remove usage of deprecated API
  chromaprint-ffmpeg-API.patch
* Mon Feb 15 2016 jengelh@inai.de
- Update to new upstream release 1.3.1
  * Support for ffmpeg 3.x
  * You can use use "-length 0" in fpcalc to get the full fingerprint
  * New function chromaprint_get_fingerprint_hash for calculating
  SimHash from the fingerprint data
* Fri Dec 18 2015 tchvatal@suse.com
- Remove needless conditional for the libdir which is in the macro
* Wed Dec  9 2015 olaf@aepfle.de
- Use pkg-config to detect ffmpeg in cmake
  chromaprint-ffmpeg-pkgconfig.patch
- Add bcond_without to use ffmpeg unconditional
* Tue Dec  8 2015 olaf@aepfle.de
- Remove broken libffmpeg requires in devel pkg
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Tue Jun 16 2015 mpluskal@suse.com
- Update to version 1.2
  * Fixed compilation with neither libswresample nor libavresample
    (#11)
  * Fixed compilation with static libav (#10)
  * Functions chromaprint_encode_fingerprint and
    chromaprint_decode_fingerprint are changed to accept const
    pointer as input
  * Added support for using the Kiss FFT library (should make
    Android port easier)
  * Removed obsolete dev tools from the package
  * More compatible DEBUG() macro
- Cleanup spec file with spec-cleaner
- Add missing dependency on boost
- Use cmake macro
* Wed Dec 10 2014 olaf@aepfle.de
- Update to version 1.1
  - Fixed potential DoS attack in fingerprint decompression code. (#6)
  - Fixed invalid memory read with some fingerprinter configurations. (#5)
  - Added support for audio format conversion with libav. (#2, Gordon Pettey)
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf
* Wed Oct 30 2013 joerg.lorenzen@ki.tng.de
- Update to version 1.0
  - Support for the latest FFmpeg API.
  - Support for reading audio from stdin in fpcalc.
  - Changed fpcalc to return non-zero status on failure.
* Tue Mar 19 2013 schwab@suse.de
- Properly determine LIB_SUFFIX
* Fri Nov  9 2012 hrvoje.senjan@gmail.com
- Update to version 0.7
  - Support for the latest FFmpeg API.
  - New (non-default) fingerprint algorithm that removes leading silence.
  - API to configure fingerprint algorithms, currently only used by
  CHROMAPRINT_ALGORITHM_TEST4.
* Tue May 29 2012 Manfred.Tremmel@iiv.de
- ffmpeg doen't include url.h anymorecompile against ffmpeg_oldabi
* Sat May 19 2012 pascal.bleser@opensuse.org
- initial version (0.6)
